# AiiDA DataNode classes for OTEAPI Strategy Configurations and Status

These classes are based on the strategy configurations and status classes in oteapi-core/oteapi/models for oteapi-core v0.1.6.

Any changes made to the oteapi-core classes need to be manually transferred into the AiiDA DataNode classes (except for default values for optional arguments, which are always retrieved automatically from oteapi-core).
